module.exports = defineTest({
	description: 'handle recursive computed member access'
});
